@@ -18,13 +18,14 @@ def main():
   gen.setEncoding("ISO-8859-1");
 
   #get output string
+  print "test output:"
   print gen.generateCString("int main(int argc, char **argv) {\n"+
                             "  HighlightApp app;\n"+
                             "  return app.run(argc, argv);\n"+
                             "}\n");
 
   # clear the instance
-  highlight.CodeGenerator_deleteInstance();
+  highlight.CodeGenerator_deleteInstance(gen);
 
 
 main()
